/*-------------------------------------------------------------------------*\

	FILE........: FFTSTAGE.H
	TYPE........: C Header File
	COMPANY.....: VoiceTronix
	AUTHOR......: David Rowe
	DATE CREATED: 10/6/96

	Function to implementing the FFT routine for the C5x.

\*-------------------------------------------------------------------------*/

#ifndef __FFTSTAGE__
#define __FFTSTAGE__

void fft_stage_1(int *data, int nn);
void fft_stage_2(int *data, int nn);
void fft_stage_3(int *data, int nn);
void fft_stage_4(int *data, int nn);
void fft_stage_5(int *data, int nn, int *cos);
void fft_stage_6(int *data, int nn, int *cos);
void fft_stage_7(int *data, int nn, int *cos);
void fft_stage_8(int *data, int nn, int *cos);
void zeroa(int *data, int N2,int i);
void zerob(int *data, int N2, int N4,int i);
void rlbutt45(int *data, int SS, int I1,int I2,int I3,int I4,int i);
void rlbuttsp(int *data, int CC,int SS, int I1,int I2,int I3,int I4,int i);
void rlbutt16(int *data, int CC,int SS, int I1,int I2,int I3,int I4,int i);

#endif	/* __FFTSTAGE__ */
